@@ -370,7 +370,9 @@ void  updateKeyboard(Uint8 scancode, int state)
    }
 }
 
-const int          JOYSTICK_DEAD_ZONE          = 8000;
+#define DEFAULT_DEAD_ZONE    8000
+
+int                joystickDeadZone            = DEFAULT_DEAD_ZONE;
 int                anyStartButtonPushedCounter = 0;
 uint32_t           windowID;
 static const float ASPECT_RATIO = float(WIDTH) / float(HEIGHT);
@@ -478,11 +480,11 @@ loop()
             break;
          }
 
-         if (e.jaxis.value < -JOYSTICK_DEAD_ZONE)
+         if (e.jaxis.value < -joystickDeadZone)
          {
             axis[e.jaxis.axis] = -1;
          }
-         else if (e.jaxis.value > JOYSTICK_DEAD_ZONE)
+         else if (e.jaxis.value > joystickDeadZone)
          {
             axis[e.jaxis.axis] = 1;
          }
@@ -500,10 +502,12 @@ loop()
             if ((axis[0] == 1) || (axis[2] == 1))
             {
                mrboom_update_input(button_right, getPlayerFromJoystickPort(e.jaxis.which), 1, false);
+               mrboom_update_input(button_left, getPlayerFromJoystickPort(e.jaxis.which), 0, false);
             }
             else if ((axis[0] == -1) || (axis[2] == -1))
             {
                mrboom_update_input(button_left, getPlayerFromJoystickPort(e.jaxis.which), 1, false);
+               mrboom_update_input(button_right, getPlayerFromJoystickPort(e.jaxis.which), 0, false);
             }
             else
             {
@@ -516,10 +520,12 @@ loop()
             if ((axis[1] == 1) || (axis[3] == 1))
             {
                mrboom_update_input(button_down, getPlayerFromJoystickPort(e.jaxis.which), 1, false);
+               mrboom_update_input(button_up, getPlayerFromJoystickPort(e.jaxis.which), 0, false);
             }
             else if ((axis[1] == -1) || (axis[3] == -1))
             {
                mrboom_update_input(button_up, getPlayerFromJoystickPort(e.jaxis.which), 1, false);
+               mrboom_update_input(button_down, getPlayerFromJoystickPort(e.jaxis.which), 0, false);
             }
             else
             {
@@ -721,9 +727,7 @@ loop()
    }
 
    mrboom_deal_with_autofire();
-   program();
-   mrboom_reset_special_keys();
-   mrboom_tick_ai();
+   mrboom_loop();
 
 #ifdef DEBUG
    if (mrboom_debug_state_failed())
@@ -765,16 +769,6 @@ loop()
             }
          }
       }
-                #if 0
-      for (int i = 0; i < MAX_TURBO; i++)
-      {
-         for (int j = 0; j < MAX_TURBO; j++)
-         {
-            printf("%d ", showFrame[i][j]);
-         }
-         printf("\n");
-      }
-                #endif
       calculateShowFrame = false;
    }
 
@@ -961,12 +955,14 @@ main(int argc, char **argv)
          { "aitest",      required_argument, 0, 'a' },
          { "nomusic",     no_argument,       0, 'z' },
          { "xbrz",        required_argument, 0, 'x' },
+         { "skynet",      no_argument,       0, 'k' },
+         { "deadzone",    required_argument, 0, 'd' },
          {             0,                 0, 0,   0 }
       };
       /* getopt_long stores the option index here. */
       int option_index = 0;
 
-      c = getopt_long(argc, argv, "hl:mscv123:4:t:f:o:a:nzx:",
+      c = getopt_long(argc, argv, "hl:mscv123:4:t:f:o:a:nzx:kd:",
                       long_options, &option_index);
 
       /* Detect the end of the options. */
@@ -981,11 +977,14 @@ main(int argc, char **argv)
          log_info("Options:\n");
          log_info("  -f <x>, --fx <x>\t\tFX volume: from 0 to 10\n");
          log_info("  -h, --help     \t\tShow summary of options\n");
-         log_info("  -l <x>, --level <x>\t\tStart in level 0:Candy 1:Pinguine 2:Pink 3:Jungle 4:Board 5:Soccer 6:Sky 7:Aliens\n");
+         log_info("  -l <x>, --level <x>\t\tStart in level 0:Candy 1:Pinguine 2:Pink\n");
+         log_info("                     \t\t3:Jungle 4:Board 5:Soccer 6:Sky 7:Aliens\n");
          log_info("  -m, --nomonster\t\tNo monster mode\n");
          log_info("  -s, --sex     \t\tSex team mode\n");
          log_info("  -c, --color     \t\tColor team mode\n");
+         log_info("  -k, --skynet     \t\tHumans vs. machines mode\n");
          log_info("  -n, --noautofire     \t\tNo autofire for bomb drop\n");
+         log_info("  -d <x>, --deadzone <x>\tSet joysticks dead zone, default is %d\n", DEFAULT_DEAD_ZONE);
          log_info("  -z, --nomusic     \t\tNo music\n");
          log_info("  -v, --version  \t\tDisplay version\n");
 #ifdef DEBUG
@@ -1085,6 +1084,11 @@ main(int argc, char **argv)
          log_info("-s option given. Sex team mode.\n");
          break;
 
+      case 'k':
+         setTeamMode(4);
+         log_info("-k option given. Skynet team mode.\n");
+         break;
+
       case '2':
          log_info("-2 option given. Slow motion for AI debugging.\n");
          slowMode = true;
@@ -1107,6 +1111,11 @@ main(int argc, char **argv)
          }
          break;
 
+      case 'd':
+         joystickDeadZone = atoi(optarg);
+         log_info("-d Joystick deadzone to %d.\n", joystickDeadZone);
+         break;
+
       default:
          abort();
       }
